@@ -3,13 +3,10 @@
 
 """Top-level package for pyhomogenize."""
 
-import pkg_resources
-
-from . import _consts as consts
-from . import _utilities as utilities
-from . import operators as op
+from . import _read_write as read_write
 from ._basics import basics
 from ._netcdf_basics import netcdf_basics
+from ._read_write import get_var_name, open_xrdataset, save_xrdataset
 from ._time_compare import time_compare
 from ._time_control import time_control
 from .cli import create_parser
@@ -18,17 +15,16 @@ from .pyhomogenize import pyhomogenize
 
 __author__ = """Ludwig Lierhammer"""
 __email__ = "ludwig.lierhammer@hereon.de"
-__version__ = "0.1.4"
+__version__ = "0.2.1"
 
 _all__ = [
-    "consts",
-    "utilities",
-    "op",
     "basics",
     "netcdf_basics",
     "time_compare",
     "time_control",
-    "create_parser",
     "test_netcdf",
     "pyhomogenize",
+    "open_xrdataset",
+    "get_var_name",
+    "save_xrdataset",
 ]
